/* 	RemoteConnector.java
 *	Copyright (c) 2006, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 22-nov-2006
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * 26-feb-2007	dennis@brains2b.nl       Username will be reported from connection or will be null		
*/
package org.brains2b.sql;

import java.sql.Connection;
import java.sql.SQLException;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

/** Implementation of Connector to connect
 * to a remote JDBC source, given by a lookup name
 * accessable through an InitialContext
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10.1 [26-feb-2007]
 */
public class RemoteConnector implements Connector {

    private Connection m_con;
    private String m_lookupName;
    
    /**
     * Constructor taking a lookupName for an InitialContext
     * to create a connection to a database
     * @param lookupName String, the lookup for the connection to use
     */
    public RemoteConnector(String lookupName) {
        m_lookupName = lookupName;
    }
    
    /**
     * {@inheritDoc}
     */
    public void close() throws SQLException {
       m_con.close();
       m_con=null;
    }

    /**
     * {@inheritDoc}
     */
    public Connection getConnection() throws SQLException {
        if (m_con==null) {
            m_con=createConnection();
        }
        return m_con;
    }

    /**
     * {@inheritDoc}
     */
    public String getUser() {
       if (m_con==null) {
           return null;
       } else {
           try {
               return m_con.getMetaData().getUserName();
           } catch (SQLException sqex) {
               return null;
           }
       }
    }

    /**
     * create the connection on the basis of the lookup name
     * @return Connection
     * @throws SQLException, thrown if the connection cannot be
     * made
     */
    private Connection createConnection() throws SQLException {
        try {
            InitialContext context = new InitialContext();
            DataSource ds= (DataSource) context.lookup(m_lookupName);
            return ds.getConnection();
        } catch (NamingException nex) {
            throw new SQLException("Could not connect to database");
        }
    }
    
    /**
     * {@inheritDoc}
     */
    public Object clone(){
        return new RemoteConnector(m_lookupName);
    }
}
