/* 	SQLHelper.java
 *	Copyright (c) 2004-2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Feb 14, 2004
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/*
 * @#History 
 * [When]      [Who]               [What] 
 * 30-01-2007  dennis@brains2b.nl  Implemented decode method
 * 18-03-2007  dennis@brains2b.nl  If the decoded string is empty return null
 * 08-10-2007  dennis@brains2b.nl  Fix limitIdentifier for names which are just long enough
 * 17-10-2007  dennis@brains2b.nl  Remove underscores from names which are still too long 
 */
package org.brains2b.sql;

/** [Short description]
 *  [Long description]
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.11.3 [17-10-2007]
 */
public final class SQLHelper {

	/** encode a String so it can be inserted into an SQL database
	 *  by replacing every quote with two quotes
	 * 
	 * @param s String, the String to encode
	 * @return String, the encoded String
	 */
	public final static String encode(String s) {
        if (s==null) return null;
		StringBuffer sb=new StringBuffer(s.length());
		for (int i=0;i<s.length();i++) {
			if (s.charAt(i)=='\'') sb.append("\'");
			sb.append(s.charAt(i));
		}
		return sb.toString();		
	}
    
    /** strip quotes from the beginning and end of a String
     * from an SQL database
     * @param s String, the String to strip
     * @return String, the stripped String
     */
    public final static String stripQuotes(String s) {
        if (s==null || s.length()==0) return null;
        s=s.trim();
        if ((s.charAt(0)=='\'' && s.charAt(s.length()-1)=='\'') || 
            (s.charAt(0)=='\"' && s.charAt(s.length()-1)=='\"')) {
            s = s.substring(1,s.length()-1);
        }
        return s;
    }
    
    /**
     * limit the identifier given by String to the length given.
     * <p>This is accomplished by removing as much non-vowels as
     * needed from the String
     * @param s String, the identifier to limit
     * @param length int, the length to limit the identifier to
     * @return String
     */
    public final static String limitIdentifier(String s, int length) {
        if (s==null || s.length()<=length) return s;
        StringBuffer sb = new StringBuffer(length);
        char[] c = s.toUpperCase().toCharArray();
        int cnt = s.length()-length;
        boolean open=false;
        for (int i=c.length-1;i>=0;i--) {
            if (open && (c[i]=='E' || c[i]=='A' || c[i]=='I' || c[i]=='U' || c[i]=='O')) {
                cnt--;
                open=true;
            } else if (c[i]=='-' || c[i]=='_') {
                open=false;
                sb.insert(0,s.charAt(i));
            } else {
                sb.insert(0,s.charAt(i));
                open=true;
            }
            if(cnt==0 || i==0) {
                cnt=i;
                break;
            }
        }
        sb.insert(0, s.substring(0,cnt));
        if (sb.length()>length) {
        	int idx = sb.lastIndexOf("_");
        	final int dif = sb.length()-length+1;
        	for (int i=0;i<dif && idx>-1;i++) {
        		sb.delete(idx, idx+1);
        		idx = sb.lastIndexOf("_");
        	}
        	if (sb.length()>length)
        	throw new RuntimeException("Cannot reasonably shorten name:" + s);
        }
        return sb.toString();
    }
}
