/* 	ParameterModel.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 31-mrt-2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * TODO write JUnit test		
*/
package org.brains2b.sql.meta;

import org.brains2b.sql.SQLRecord;

/** Wrapper around the parameter definition from DatabaseMetaData
 * <p>This ParameterModel has a method {@link #setValue(Object)} to
 * set a value for this parameter to be used in calling the Procedure
 * it belongs to</p>
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 1.00 [Mrt 30, 2007]
 * @see SQLMetaData
 * @see SQLRecord
 */
public class ParameterModel implements SQLMetaModel {

    private SQLRecord m_record;
    private transient Object m_value;
    
     /**
     * Create an ParameterModel on the basis of this SQLRecord
     * @param record SQLRecord, the record containing the 
     * information on this column
     */
    public ParameterModel(SQLRecord record) {
        super();
        m_record = record;
    }
    
    /**
     * {@inheritDoc}
     */
    public String getName() {
        return m_record.getString("COLUMN_NAME");
    }

    /**
     * {@inheritDoc}
     */
    public SQLRecord getRecord() {
        return m_record;
    }

    /**
     * {@inheritDoc}
     */
    public String getType() {
        return m_record.getString("TYPE_NAME");
    }

    /**
     * get the datatype as defined in <code>java.sql.Type</code>
     * @return int, the type of the data in this column
     */
    public int getDataType() {
        return getRecord().getIntValue("DATA_TYPE");
    }
    
     /**
     * get the datatype as defined in <code>java.sql.Type</code>
     * @return int, the type of the data in this column
     */
    public int getParamType() {
        return getRecord().getIntValue("COLUMN_TYPE");
    }

    
    /**
     * get the value for this parameter
     * @return Object
     */
    public Object getValue() {
        return m_value;
    }

    /**
     * set the value for this parameter
     * @param value Object
     */
    public void setValue(Object value) {
        m_value = value;
    }

}
