/* 	SqlKeyWords.java
 *	Copyright (c) 2005, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]           [Who]                       [What]
 * 09-10-2005   dennis@brains2b.nl  Added support for 'REVERSE'
 */
package org.brains2b.sql.meta;

import java.util.ArrayList;

/** Class that implements one single static function <code>isReserved</code>
 * which checks if a <code>String</code> is a SQL reserved word.
 * 
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10.1 [Oct 10, 2005]
 */
public class SQLKeyWords {
	
	/** list of Java reserved words */
	private static ArrayList KEYWORDS= new ArrayList(232);
	
	static {
        KEYWORDS.add("ABSOLUTE");
        KEYWORDS.add("ACTION");
        KEYWORDS.add("ADD");
        KEYWORDS.add("ALL");
        KEYWORDS.add("ALLOCATE");
        KEYWORDS.add("ALTER");
        KEYWORDS.add("AND");
        KEYWORDS.add("ANY");
        KEYWORDS.add("ARE");
        KEYWORDS.add("AS");
        KEYWORDS.add("ASC");
        KEYWORDS.add("ASSERTION");
        KEYWORDS.add("AT");
        KEYWORDS.add("AUTHORIZATION");
        KEYWORDS.add("AVG");
        KEYWORDS.add("BEGIN");
        KEYWORDS.add("BETWEEN");
        KEYWORDS.add("BIT");
        KEYWORDS.add("BIT_LENGTH");
        KEYWORDS.add("BOTH");
        KEYWORDS.add("BY");
        KEYWORDS.add("CASCADE");
        KEYWORDS.add("CASE");
        KEYWORDS.add("CAST");
        KEYWORDS.add("CATALOG");
        KEYWORDS.add("CHAR");
        KEYWORDS.add("CHARACTER");
        KEYWORDS.add("CHARACTER_LENGTH");
        KEYWORDS.add("CHAR_LENGTH");
        KEYWORDS.add("CHECK");
        KEYWORDS.add("CLOSE");
        KEYWORDS.add("COALESCE");
        KEYWORDS.add("COBOL");
        KEYWORDS.add("COLLATE");
        KEYWORDS.add("COLLATION");
        KEYWORDS.add("COLUMN");
        KEYWORDS.add("COMMIT");
        KEYWORDS.add("CONNECT");
        KEYWORDS.add("CONNECTION");
        KEYWORDS.add("CONSTRAINT");
        KEYWORDS.add("CONSTRAINTS");
        KEYWORDS.add("CONTINUE");
        KEYWORDS.add("CONVERT");
        KEYWORDS.add("CORRESPONDING");
        KEYWORDS.add("COUNT");
        KEYWORDS.add("CREATE");
        KEYWORDS.add("CROSS");
        KEYWORDS.add("CURRENT");
        KEYWORDS.add("CURRENT_DATE");
        KEYWORDS.add("CURRENT_TIME");
        KEYWORDS.add("CURRENT_TIMESTAMP");
        KEYWORDS.add("CURRENT_USER");
        KEYWORDS.add("CURSOR");
        KEYWORDS.add("DATE");
        KEYWORDS.add("DAY");
        KEYWORDS.add("DEALLOCATE");
        KEYWORDS.add("DEC");
        KEYWORDS.add("DECIMAL");
        KEYWORDS.add("DECLARE");
        KEYWORDS.add("DEFAULT");
        KEYWORDS.add("DEFERRABLE");
        KEYWORDS.add("DEFERRED");
        KEYWORDS.add("DELETE");
        KEYWORDS.add("DESC");
        KEYWORDS.add("DESCRIBE");
        KEYWORDS.add("DESCRIPTOR");
        KEYWORDS.add("DIAGNOSTICS");
        KEYWORDS.add("DISCONNECT");
        KEYWORDS.add("DISTINCT");
        KEYWORDS.add("DOMAIN");
        KEYWORDS.add("DOUBLE");
        KEYWORDS.add("DROP");
        KEYWORDS.add("ELSE");
        KEYWORDS.add("END");
        KEYWORDS.add("ENDEXEC");
        KEYWORDS.add("ESCAPE");
        KEYWORDS.add("EXCEPT");
        KEYWORDS.add("EXCEPTION");
        KEYWORDS.add("EXEC");
        KEYWORDS.add("EXECUTE");
        KEYWORDS.add("EXISTS");
        KEYWORDS.add("EXTERNAL");
        KEYWORDS.add("EXTRACT");
        KEYWORDS.add("FALSE");
        KEYWORDS.add("FETCH");
        KEYWORDS.add("FILE");
        KEYWORDS.add("FIRST");
        KEYWORDS.add("FLOAT");
        KEYWORDS.add("FOR");
        KEYWORDS.add("FOREIGN");
        KEYWORDS.add("FORTRAN");
        KEYWORDS.add("FOUND");
        KEYWORDS.add("FROM");
        KEYWORDS.add("FULL");
        KEYWORDS.add("FUNCTION");
        KEYWORDS.add("GET");
        KEYWORDS.add("GLOBAL");
        KEYWORDS.add("GO");
        KEYWORDS.add("GOTO");
        KEYWORDS.add("GRANT");
        KEYWORDS.add("GROUP");
        KEYWORDS.add("HAVING");
        KEYWORDS.add("HOUR");
        KEYWORDS.add("IDENTITY");
        KEYWORDS.add("IMMEDIATE");
        KEYWORDS.add("IN");
        KEYWORDS.add("INDICATOR");
        KEYWORDS.add("INITIALLY");
        KEYWORDS.add("INNER");
        KEYWORDS.add("INPUT");
        KEYWORDS.add("INSENSITIVE");
        KEYWORDS.add("INSERT");
        KEYWORDS.add("INT");
        KEYWORDS.add("INTEGER");
        KEYWORDS.add("INTERSECT");
        KEYWORDS.add("INTERVAL");
        KEYWORDS.add("INTO");
        KEYWORDS.add("IS");
        KEYWORDS.add("ISOLATION");
        KEYWORDS.add("JOIN");
        KEYWORDS.add("KEY");
        KEYWORDS.add("LANGUAGE");
        KEYWORDS.add("LAST");
        KEYWORDS.add("LEADING");
        KEYWORDS.add("LEFT");
        KEYWORDS.add("LEVEL");
        KEYWORDS.add("LIKE");
        KEYWORDS.add("LOCAL");
        KEYWORDS.add("LOWER");
        KEYWORDS.add("MATCH");
        KEYWORDS.add("MAX");
        KEYWORDS.add("MIN");
        KEYWORDS.add("MINUTE");
        KEYWORDS.add("MODULE");
        KEYWORDS.add("MONTH");
        KEYWORDS.add("NAMES");
        KEYWORDS.add("NATIONAL");
        KEYWORDS.add("NATURAL");
        KEYWORDS.add("NCHAR");
        KEYWORDS.add("NEXT");
        KEYWORDS.add("NO");
        KEYWORDS.add("NOT");
        KEYWORDS.add("NULL");
        KEYWORDS.add("NULLIF");
        KEYWORDS.add("NUMERIC");
        KEYWORDS.add("OCTET_LENGTH");
        KEYWORDS.add("OF");
        KEYWORDS.add("ON");
        KEYWORDS.add("ONLY");
        KEYWORDS.add("OPEN");
        KEYWORDS.add("OPTION");
        KEYWORDS.add("OR");
        KEYWORDS.add("ORDER");
        KEYWORDS.add("OUTER");
        KEYWORDS.add("OUTPUT");
        KEYWORDS.add("OVERLAPS");
        KEYWORDS.add("PAD");
        KEYWORDS.add("PARTIAL");
        KEYWORDS.add("PASCAL");
        KEYWORDS.add("PLI");
        KEYWORDS.add("POSITION");
        KEYWORDS.add("PRECISION");
        KEYWORDS.add("PREPARE");
        KEYWORDS.add("PRESERVE");
        KEYWORDS.add("PRIMARY");
        KEYWORDS.add("PRIOR");
        KEYWORDS.add("PRIVILEGES");
        KEYWORDS.add("PROCEDURE");
        KEYWORDS.add("PUBLIC");
        KEYWORDS.add("READ");
        KEYWORDS.add("REAL");
        KEYWORDS.add("REFERENCES");
        KEYWORDS.add("RELATIVE");
        KEYWORDS.add("RESTRICT");
        KEYWORDS.add("REVOKE");
        KEYWORDS.add("REVERSE");
        KEYWORDS.add("RIGHT");
        KEYWORDS.add("ROLE");
        KEYWORDS.add("ROLLBACK");
        KEYWORDS.add("ROWS");
        KEYWORDS.add("SCHEMA");
        KEYWORDS.add("SCROLL");
        KEYWORDS.add("SECOND");
        KEYWORDS.add("SECTION");
        KEYWORDS.add("SELECT");
        KEYWORDS.add("SESSION_USER");
        KEYWORDS.add("SET");
        KEYWORDS.add("SIZE");
        KEYWORDS.add("SMALLINT");
        KEYWORDS.add("SOME");
        KEYWORDS.add("SPACE");
        KEYWORDS.add("SQL");
        KEYWORDS.add("SQLCODE");
        KEYWORDS.add("SQLERROR");
        KEYWORDS.add("SQLSTATE");
        KEYWORDS.add("SUBSTRING");
        KEYWORDS.add("SUM");
        KEYWORDS.add("SYSTEM_USER");
        KEYWORDS.add("TABLE");
        KEYWORDS.add("TEMPORARY");
        KEYWORDS.add("THEN");
        KEYWORDS.add("TIME");
        KEYWORDS.add("TIMESTAMP");
        KEYWORDS.add("TIMEZONE_HOUR");
        KEYWORDS.add("TIMEZONE_MINUTE");
        KEYWORDS.add("TO");
        KEYWORDS.add("TRAILING");
        KEYWORDS.add("TRANSACTION");
        KEYWORDS.add("TRANSLATE");
        KEYWORDS.add("TRANSLATION");
        KEYWORDS.add("TRIM");
        KEYWORDS.add("TRUE");
        KEYWORDS.add("UNION");
        KEYWORDS.add("UNIQUE");
        KEYWORDS.add("UNKNOWN");
        KEYWORDS.add("UPDATE");
        KEYWORDS.add("UPPER");
        KEYWORDS.add("USAGE");
        KEYWORDS.add("USER");
        KEYWORDS.add("USING");
        KEYWORDS.add("VALUE");
        KEYWORDS.add("VALUES");
        KEYWORDS.add("VARCHAR");
        KEYWORDS.add("VARYING");
        KEYWORDS.add("VIEW");
        KEYWORDS.add("WHEN");
        KEYWORDS.add("WHENEVER");
        KEYWORDS.add("WHERE");
        KEYWORDS.add("WITH");
        KEYWORDS.add("WORK");
        KEYWORDS.add("WRITE");
        KEYWORDS.add("YEAR");
        KEYWORDS.add("ZONE");
	}
	
	/**
	 * Default Constructor
	 * <p>constructor made private to prevent instantiation
	 */
	private SQLKeyWords() {
		super();
	}
	
	/**
	 * check if a String is a Java reserved word/keyword 
	 * @param name String, the value to check
	 * @return boolean, true if the String is a keyword, otherwise false, also if the
	 * name is null.
	 */
	public static boolean isReserved(String name) {
		if (name==null) return false;
		return KEYWORDS.contains(name.toUpperCase());
	}

}
