/* 	SQLMetaModel.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: 25-mrt-2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.sql.meta;

import org.brains2b.sql.SQLRecord;

/**
 * Interface that defines general information for the wrapper
 * of the database meta models on the basis of {@link SQLRecord}
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 1.00 [25-03-2007]
 * @see SQLRecord
 */
public interface SQLMetaModel {

    /**
     * get the type of Object defined by the meta model
     * <p>returned value depends on the model: TABLE,COLUMN,INDEX
     * @return String
     */
    public String getType();
    
    /**
     * get the name for this model's instance
     * <p>This is equal to the name of the table,column, etc. 
     * @return String
     */
    public String getName();
    
    /**
     * the record which defines all the values for the model
     * @return SQLRecord
     */
    public SQLRecord getRecord();
}
