/* 	Stream.java
 *	Copyright (c) 2008, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Mar 18, 2008
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.sql.meta.types;

import java.io.InputStream;
import java.io.OutputStream;
import java.sql.SQLException;

/** 
 * Simple interface that defines a data-type as stream and supplies
 * both an output as input stream for the datatype.
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.90 [Mar 18, 2008]
 */
public interface Stream {

	/**
	 * get the input stream
	 * @return InputStream
	 * @throws SQLException, if the InputStream cannot be created
	 */
	public InputStream getInputStream() throws SQLException;
	
	/**
	 * get the output stream
	 * @return OutputStream
	 * @throws SQLException, if the OutputStream cannot be created
	 */
	public OutputStream getOutputStream() throws SQLException;
	
	/**
	 * check if the input or output was ever used to prevent unecessary
	 * reading and writing for streams that were never accessed.
	 * @return boolean, true if stream was accessed, false otherwise
	 * @throws SQLException, if the Input or OutputStream cannot be accessed
	 */
	public boolean isAccessed() throws SQLException;
}
