/* 	DynamicClassLoaderTest.java
 *	Copyright (c) 2006, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Feb 12, 2006
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.loader;

import java.io.File;
import java.net.URL;

import org.brains2b.loader.DynamicClassLoader;
import org.brains2b.log.Logger;
import org.brains2b.sql.LocalConnector;
import org.brains2b.task.DefaultTask;
import org.brains2b.task.Task;

import junit.framework.TestCase;

/**
 *  JUnit test for org.brains2b.loader.DynamicClassLoader
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [Feb 12, 2006]
 * @see org.brains2b.loader.DynamicClassLoader
 */
public class DynamicClassLoaderTest extends TestCase {

	private final static String root= System.getProperty("user.dir", ".");
	
	public DynamicClassLoaderTest(String arg0) {
		super(arg0);
	}

	
	public void testLoadAllFromDir() {
		try {
			Class[] cs=DynamicClassLoader.loadClasses(new URL[] {new File(root,"bld").toURL()});
			assertContains(LocalConnector.class,cs);
		} catch (Exception cnex) {
			assertTrue(cnex.getMessage(),false);
		}
		
	}
	
	public void testLoadAllFromJar() {
		try {
			Class[] cs=DynamicClassLoader.loadClasses(new URL[] {new File(root,"lib/TwelBox.jar").toURL()});
			assertContains(Logger.class,cs);
		} catch (Exception cnex) {
			assertTrue(cnex.getMessage(),false);
		}
		
	}
	
	public void testMixedMultiple() {
		try {
			Class[] cs=DynamicClassLoader.loadClasses(new URL[] {
					new File(root,"bld").toURL(),
					new File(root,"lib/TwelBox.jar").toURL()});
		assertContains(LocalConnector.class,cs);	
		assertContains(Logger.class,cs);	
		} catch (Exception cnex) {
			assertTrue(cnex.getMessage(),false);
		}
	}
	
	public void testfindImplementation() {
		try {
			Class[] cs=DynamicClassLoader.findImplementation(Task.class, new URL[] {new File(System.getProperty("user.dir"),"lib/TwelBox.jar").toURL()});
			assertEquals(2,cs.length);
			assertEquals(DefaultTask.class,cs[0]);
            assertEquals(Task.class,cs[1]);
		} catch (Exception cnex) {
			assertTrue(cnex.getMessage(),false);
		}
		
	}

	protected void assertContains(Object o, Object[] list) {
		if (list== null || o == null) return;
		boolean b=false;
		for (int i=0;i<list.length;i++) {
			if (o.equals(list[i])) { b= true; break;}
		}
		assertTrue("Object is not contained in list",b);
	}
}
