package test.org.brains2b.sql;

import java.sql.Connection;
import java.sql.SQLException;

import junit.framework.TestCase;

import org.brains2b.sql.LocalConnector;

/** Unit test for org.brains2b.sql.Connector
 *  <p><i>Note: </i> This test depends on database server information
 *  Both mysql and oracle are defined. 
 *  Changing the connection information requires you to change
 *  <LI>setUp()
 *  <LI>testGetDbName()
 * 	<LI>testGetServerName()
 *  <p><i>Note: </i>Remember if you comment out the mysql driver to change the
 *  all tests to only use the available connection.
 *  <p><i>Note: </i>Don't forget to add the drivers to your classpath
 * <p>TODO unit test includes names and passwords which is not okay
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.1 [03-07-2003]
 */
public class LocalConnectorTest extends TestCase {

	private LocalConnector mysql;
	private LocalConnector oracle;

    /**
     * Constructor for ConnectorTest.
     * @param arg0
     */
    public LocalConnectorTest(String arg0) {
        super(arg0);
    }

    public static void main(String[] args) {
        junit.swingui.TestRunner.run(LocalConnectorTest.class);
    }

	public void setUp() throws Exception {
			mysql=new LocalConnector(
				"/usr/local/java/lib/mysql-connector-java-3.0.9-stable-bin.jar",
    			"org.gjt.mm.mysql.Driver",
    			"jdbc:mysql://arthur/dutch",
    			"dennis",
    			"gleick42"
    			);
		try {
			mysql.getConnection();
    	} catch (SQLException sqex) {
			throw new Exception("MySql database cannot be found, change connection or remove it from test");

    	}

		oracle= new LocalConnector(
			"/usr/local/java/lib/ojdbc14.jar",
			"oracle.jdbc.driver.OracleDriver",
			"jdbc:oracle:thin:@arthur:1521:merlin",
			"DUTCH",
			"LION"	
		);
		
		try {
			oracle.getConnection();
    	} catch (SQLException sqex) {
			throw new Exception("Oracle database cannot be found, change connection or remove it from test");

    	}
	}


    public void testGetConnection() {
    	try {
    		Connection con=mysql.getConnection();
    		assertNotNull(con);
    	} catch (SQLException sqex) {
    		assertTrue(sqex.getMessage(),false);
    	}
    }

    public void testClose() {
    	try {
    		Connection con=mysql.getConnection();
    		assertNotNull(con);
    		con.close();
    		assertTrue(con.isClosed());
    	} catch (SQLException sqex) {
    		assertTrue(sqex.getMessage(),false);
    	}
    }

    public void testGetUser() {
    	assertEquals("dennis",mysql.getUser());
        assertEquals("DUTCH",oracle.getUser());
    	
    }

    public void testGetDbName() {
    	assertEquals("dutch",mysql.getDbName());
    	assertEquals("merlin",oracle.getDbName());
    }

    public void testGetServerName() {
    	assertEquals("arthur",mysql.getServerName());
    	assertEquals("arthur",oracle.getServerName());

    }


}
