/* 	SQLHelperTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: May 31, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package test.org.brains2b.sql;

import junit.framework.TestCase;

import org.brains2b.sql.SQLHelper;

/** Unit test for {@link SQLHelper}
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 1.00 [May 31, 2007]
 * @see SQLHelper
 */
public class SQLHelperTest extends TestCase {

    public SQLHelperTest(String arg0) {
        super(arg0);
    }

    public void testLimitIdentifier() {
       assertEquals("NOT_LIMITED", SQLHelper.limitIdentifier("NOT_LIMITED", 32));
       assertNull(SQLHelper.limitIdentifier(null, 32));
       String result =SQLHelper.limitIdentifier("AANTAL_MET_EEN_NAAM_LANGER_DAN_32_CHARACTERS", 32);
       assertEquals("AANTL_MT_N_NM_LNGR_DN_32_CHRCTRS",result);       
       try {
           result =SQLHelper.limitIdentifier("XXNTXL_MXT_XXN_NXXM_LXNGXR_DXN_32_CHXRXCTXRS", 32);
           assertTrue("This one should throw a runtime exception",false);
       } catch (RuntimeException rex) {
           
       }
    }
    
    public void testEncode() {
        assertEquals("Land''s end''s watersupply",SQLHelper.encode("Land's end's watersupply"));
        assertNull(SQLHelper.encode(null));
        assertEquals("''",SQLHelper.encode("'"));
    }

    public void testStripQuotes() {
        assertEquals("Not Quoted",SQLHelper.stripQuotes("'Not Quoted'"));
        assertEquals("quote's quote",SQLHelper.stripQuotes("'quote's quote'"));
        assertEquals("Nothing to do",SQLHelper.stripQuotes("Nothing to do"));
        assertEquals("Nothing to do'",SQLHelper.stripQuotes("Nothing to do'"));
        assertEquals("quote's quote",SQLHelper.stripQuotes("'quote's quote'       "));
        assertNull(SQLHelper.stripQuotes(null));
    }
}
