/* 	ConstraintModelTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: May 5, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.sql.meta;

import java.sql.SQLException;
import java.util.List;

import org.brains2b.sql.meta.ColumnModel;
import org.brains2b.sql.meta.ConstraintModel;
import org.brains2b.sql.meta.SQLMetaData;

/** Testcase for ConstraintModel
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [May 5, 2007]
 * @see org.brains2b.sql.meta.ColumnModel
 */
public class ConstraintModelTest extends ConnectedTestCase {

    public ConstraintModelTest(String arg0) {
        super(arg0);
    }

    public void testConstructor() {
         try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l= meta.getConstraints(null, getConnector().getUser(), "PROGRAM",null);
            assertEquals(3, l.size());
            ConstraintModel coPk = (ConstraintModel) l.get(0);
            ConstraintModel coFk = (ConstraintModel) l.get(1);
            
            assertEquals(ConstraintModel.PRIMARY_KEY, coPk.getType());
            assertEquals(ConstraintModel.FOREIGN_KEY, coFk.getType());
            
            assertEquals("PROGRAM", coPk.getTableName());
            assertNotNull(coPk.getColumns().get(0));
            ColumnModel cmPk = (ColumnModel) coPk.getColumns().get(0);
            assertEquals("ID",cmPk.getName());
            assertEquals("PROGRAM",cmPk.getTableName());
            
            assertEquals("PROGRAM", coFk.getTableName());
            ColumnModel cmFk = (ColumnModel) coFk.getColumns().get(0);
            assertEquals("COURSE_ID",cmFk.getName());
            assertEquals("PROGRAM",cmFk.getTableName());
            cmFk = (ColumnModel) coFk.getColumns().get(1);
            assertEquals("ID",cmFk.getName());
            assertEquals("COURSE",cmFk.getTableName());
            
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
    }
    
    public void testType() {
         try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l= meta.getConstraints(null, getConnector().getUser(), "PERSON",ConstraintModel.PRIMARY_KEY);
            assertEquals(1, l.size());
            ConstraintModel coPk = (ConstraintModel) l.get(0);
            
            assertEquals(ConstraintModel.PRIMARY_KEY, coPk.getType());
            assertEquals("PERSON", coPk.getTableName());
            assertNotNull(coPk.getColumns().get(0));
            ColumnModel cmPk = (ColumnModel) coPk.getColumns().get(0);
            assertEquals("ID",cmPk.getName());
            assertEquals("PERSON",cmPk.getTableName());
            
            l= meta.getConstraints(null, getConnector().getUser(), "PROGRAM",ConstraintModel.FOREIGN_KEY);
            assertEquals(2, l.size());
            
            ConstraintModel coFk = (ConstraintModel) l.get(0);
            assertEquals(ConstraintModel.FOREIGN_KEY, coFk.getType());
            assertEquals("PROGRAM", coFk.getTableName());
            ColumnModel cmFk = (ColumnModel) coFk.getColumns().get(1);
            assertEquals("ID",cmFk.getName());
            assertEquals("COURSE",cmFk.getTableName());
            
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
    }
    
}
