/* 	TableModelTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Jul 13, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.sql.meta;

import java.sql.SQLException;
import java.util.List;

import org.brains2b.sql.meta.ColumnModel;
import org.brains2b.sql.meta.ConstraintModel;
import org.brains2b.sql.meta.IndexModel;
import org.brains2b.sql.meta.SQLMetaData;
import org.brains2b.sql.meta.TableModel;

/** Unit test for {@link TableModel}
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 1.00 [Jul 13, 2007]
 * @see TableModel
 */
public class TableModelTest extends ConnectedTestCase {

    public TableModelTest(String name) {
        super(name);
    }
    
    public void testDefault() {
        try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l = meta.getTables(null,"DUTCH","PERSON");
            assertEquals(1,l.size());
            TableModel table = (TableModel) l.get(0);
            assertNotNull(table.getRecord());
            assertNull(table.getCatalog());
            assertEquals("PERSON",table.getName());
            assertEquals("DUTCH",table.getSchema());
            assertEquals("TABLE",table.getType());
            assertNull(table.getRemarks());
            assertNull(table.getColumns());
            assertNull(table.getIndices());
            assertNull(table.getPrimaryKey());
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
    }
    
    public void testColumns() {
        try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l = meta.getTables(null,"DUTCH","PERSON");
            assertEquals(1,l.size());
            TableModel table = (TableModel) l.get(0);
            meta.setColumns(table);
            assertEquals(6, table.getColumns().size());
            assertEquals(ColumnModel.class, table.getColumns().get(0).getClass());
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
    }
    
    public void testIndices() {
        try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l = meta.getTables(null,"DUTCH","PERSON");
            assertEquals(1,l.size());
            TableModel table = (TableModel) l.get(0);
            meta.setIndices(table,false);
            assertEquals(1, table.getIndices().size());
            assertEquals(IndexModel.class, table.getIndices().get(0).getClass());
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
    }
    
    public void testPrimaryKey() {
        try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l = meta.getTables(null,"DUTCH","PERSON");
            assertEquals(1,l.size());
            TableModel table = (TableModel) l.get(0);
            meta.setPrimaryKey(table);
            assertNotNull(table.getPrimaryKey());
            assertEquals(ConstraintModel.class, table.getPrimaryKey().getClass());
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
        
        //implied by unique Index
        try {
            SQLMetaData meta = new SQLMetaData(getConnector().getConnection());
            List l = meta.getTables(null,"DUTCH","LOCALIZED_RESOURCE");
            assertEquals(1,l.size());
            TableModel table = (TableModel) l.get(0);
            meta.setColumns(table);
            meta.setPrimaryKey(table);
            assertNotNull(table.getPrimaryKey());
            assertEquals(ConstraintModel.class, table.getPrimaryKey().getClass());
        } catch (SQLException sqex) {
            assertTrue(sqex.getMessage(), false);
        }
    }
    
    
}
