/* 	typesTest.java
 *	Copyright (c) 2004, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: May 28, 2004-2006
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
* [When]		[Who]					[What]
* 8-feb-2006	dennis@brains2b.nl      Fixed test for difference between double/float
* 17-01-2008	dennis@brains2b.nl      changes for new TypesInfo  		
*/
package test.org.brains2b.sql.meta;

import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.Date;

import org.brains2b.sql.meta.TypesInfo;
import org.brains2b.sql.meta.types.Stream;

/** Unit test for org.brains2b.sql.meta.types
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10.1 [08-02-2006]
 */
public class Types2JavaTest extends ConnectedTestCase {

	/**
	 * Constructor for typesTest.
	 * @param arg0
	 */
	public Types2JavaTest(String arg0) {
		super(arg0);
	}

	public void testGetOracleDatatype() {
		try {
			TypesInfo types= new TypesInfo(getConnector().getConnection());
			assertEquals("NUMBER",types.getSQLType(java.sql.Types.DECIMAL));
			assertEquals("NUMBER",types.getSQLType(java.sql.Types.INTEGER));
			assertEquals("VARCHAR2",types.getSQLType(java.sql.Types.VARCHAR));
			assertEquals("CHAR",types.getSQLType(java.sql.Types.CHAR));
			assertEquals("DATE",types.getSQLType(java.sql.Types.DATE));
			assertEquals("DATE",types.getSQLType(java.sql.Types.DATE));
			assertEquals("BLOB",types.getSQLType(java.sql.Types.OTHER));
			assertEquals("/* value: 2000 cannot be determinend */",types.getSQLType(java.sql.Types.JAVA_OBJECT));
		} catch (SQLException sqex) {
			assertTrue(sqex.getMessage(),false);
		}
	}

	public void testgetJavaTypeName() {
		try {
			TypesInfo types= new TypesInfo(getConnector().getConnection());
			assertEquals("Date",types.getJavaTypeName(java.sql.Types.DATE,11,0));
			assertEquals("Timestamp",types.getJavaTypeName(java.sql.Types.TIME,11,0));
			assertEquals("Timestamp",types.getJavaTypeName(java.sql.Types.TIMESTAMP,11,0));
	
			assertEquals("String",types.getJavaTypeName(java.sql.Types.VARCHAR,500,0));
			assertEquals("Stream",types.getJavaTypeName(java.sql.Types.LONGVARBINARY,-1,0));
			
			assertEquals("boolean",types.getJavaTypeName(java.sql.Types.BIT,1,0));
			assertEquals("short",types.getJavaTypeName(java.sql.Types.SMALLINT,1,0));
			assertEquals("int",types.getJavaTypeName(java.sql.Types.INTEGER,1,0));
			assertEquals("double",types.getJavaTypeName(java.sql.Types.NUMERIC,10,2));
			assertEquals("float",types.getJavaTypeName(java.sql.Types.DECIMAL,22,2));
		} catch (SQLException sqex) {
			assertTrue(sqex.getMessage(),false);
		}
	}

	/*
	 * Test for Class getJavaType(int, int, int)
	 */
	public void testGetJavaTypeintintint() {
		try {
			TypesInfo types= new TypesInfo(getConnector().getConnection());
			assertEquals(Date.class,types.getJavaType(java.sql.Types.DATE,11,0));
			assertEquals(Timestamp.class,types.getJavaType(java.sql.Types.TIME,11,0));
			assertEquals(Timestamp.class,types.getJavaType(java.sql.Types.TIMESTAMP,11,0));
	
			assertEquals(String.class,types.getJavaType(java.sql.Types.VARCHAR,500,0));
			assertEquals(Stream.class,types.getJavaType(java.sql.Types.LONGVARBINARY,-1,0));
	
			assertEquals(Boolean.TYPE,types.getJavaType(java.sql.Types.BIT,1,0));
			assertEquals(Short.TYPE,types.getJavaType(java.sql.Types.SMALLINT,1,0));
			assertEquals(Integer.TYPE,types.getJavaType(java.sql.Types.INTEGER,1,0));
			assertEquals(Double.TYPE,types.getJavaType(java.sql.Types.NUMERIC,10,2));
			assertEquals(Float.TYPE,types.getJavaType(java.sql.Types.DECIMAL,22,2));
		} catch (SQLException sqex) {
			assertTrue(sqex.getMessage(),false);
		}
	}

	public void testGetDataType() {
		try {
			TypesInfo types= new TypesInfo(getConnector().getConnection());
			assertEquals(java.sql.Types.DATE,types.getDataType(Date.class));
			assertEquals(java.sql.Types.TIMESTAMP,types.getDataType(Timestamp.class));
			assertEquals(java.sql.Types.TIMESTAMP,types.getDataType(Timestamp.class));
	
			assertEquals(java.sql.Types.VARCHAR,types.getDataType(String.class));
	
			assertEquals(java.sql.Types.BIT,types.getDataType(Boolean.TYPE));
			assertEquals(java.sql.Types.SMALLINT,types.getDataType(Short.TYPE));
			assertEquals(java.sql.Types.INTEGER,types.getDataType(Integer.TYPE));
			assertEquals(java.sql.Types.DECIMAL,types.getDataType(Double.TYPE));
			assertEquals(java.sql.Types.DECIMAL,types.getDataType(Float.TYPE));
		} catch (SQLException sqex) {
			assertTrue(sqex.getMessage(),false);
		}
	}

	/*
	 * Test for int getJavaType(int)
	 */
	public void testGetJavaTypeint() {
		try {
			TypesInfo types= new TypesInfo(getConnector().getConnection());
			assertTrue(!types.isPrimitive(java.sql.Types.DATE));
			assertTrue(!types.isPrimitive(java.sql.Types.TIME));
			assertTrue(!types.isPrimitive(java.sql.Types.TIMESTAMP));
	
			assertTrue(!types.isPrimitive(java.sql.Types.VARCHAR));
			assertTrue(!types.isPrimitive(java.sql.Types.LONGVARBINARY));
	
			assertTrue(types.isPrimitive(java.sql.Types.BIT));
			assertTrue(types.isPrimitive(java.sql.Types.SMALLINT));
			assertTrue(types.isPrimitive(java.sql.Types.INTEGER));
			assertTrue(types.isPrimitive(java.sql.Types.NUMERIC));
			assertTrue(types.isPrimitive(java.sql.Types.DECIMAL));
		} catch (SQLException sqex) {
			assertTrue(sqex.getMessage(),false);
		}
		
	}

}
